Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Inputs ¶
type Inputs struct {
URL string `validate:"required,url" query:"url"`
Title string `validate:"required" query:"title"`
Description string `query:"description"`
Image string `query:"image"`
}
Inputs represents the data that is expected to be provided when adding a new entry to the reading list. The `query` struct tags are so this struct can be used in Fiber (github.com/gofiber/fiber/v2) applications and its (*ctx).QueryParser method
Click to show internal directories.
Click to hide internal directories.